Skip to contents

This method provides a summary of the CoPro object, including the number of cells, genes, slides, and cell types of interest. It also displays the processing steps completed and the parameters used.

Usage

# S4 method for class 'CoPro'
show(object)

Arguments

object

A CoPro object

Value

The CoPro object (invisibly)