Take a subset of the original matrix based on cell types of interest. The original data are stored without being thrown away
See also
newCoProSingle(), newCoProMulti(), CreateCoPro()
Other object-creation:
asCoPro,
newCoProMulti(),
newCoProSingle()