CoPro object of spatial transcriptomics data
Slots
normalizedDataA
matrixobject to store normalized data.normalizedDataSubA
matrixobject to store the subset of the normalized data. The subset only contain relevant cell types of interest specified by the user.locationDataA
data.frameobject to store the location. It should either contain two columns named by "x" and "y", or three columns named by "x", "y", and "z". No other names allowedlocationDataSubA
data.frameobject to store the subset of the location data.metaDataA
data.frameobject to store metadata for each cell.metaDataSubA
data.frameobject to store the subset of the meta data.cellTypesA
vectorobject with elements being character. It should match the number of cells in the data matrix and each represents a cell type label of a cell.cellTypesSubA
vectorobject with elements being character. It stores the subset of the cell type labels.cellTypesOfInterestA
vectorobject with elements being character. Specifies the cell types of interest. It will be used to subset the datasetpcaResultsA
listobject storing PCA results after integration. Recommended structure:list(slideID = list(cellType = pc_matrix)).pcaGlobalA
listobject storing PCA results for each cell type.distancesA
listobject to store the pairwise distances between any two cell types of interest.geneListA
vectorobject with elements being character. To store the gene names.kernelMatricesA
listobject. To store the kernel matrix generated from the distance matrices.sigmaValuesA
vectorobject with elements being numeric. To store a set of sigma values used for generating the kernel matrix.nPCAA single numeric value. Number of PCs to retain for downstream analyses.
nCCA single numeric value. Number of canonical components to retain for downstream analyses.
scalePCsA
logicalvalue. Whether to scale each PC before computing skrCCAskrCCAOutA
listobject. Output from the skrCCA.skrCCAPermuOutA
listobject. Output from the skrCCA after permutation. This helps establish the null distributioncellPermuA
listobject that stores the cell permutation labelsnPermuA
numericvalue specifying the number of permutations conducted.cellScoresA
matrixobject. Cell scores for each cell type.geneScoresA
matrixobject. Gene scores for each cell type.geneScoresRegressionA
listobject. Regression-based gene scores. For each gene, the regression coefficient of gene expression on the cell score is used as the gene weight. This avoids collinearity issues present in the PCA back-projection approach stored ingeneScores.geneScoresTestA
listobject. Tested gene scoresnormalizedCorrelationA
listobject. Normalized correlation values for each sigma value.bidirCorrelationA
listobject. Bidirectional correlation values for each sigma value.normalizedCorrelationPermuA
listobject. Normalized correlation values for each sigma value after permutationbidirCorrelationPermuA
listobject. Bidirectional correlation values for each sigma value after permutationsigmaValueChoiceA
numericvalue. The optimal sigma squared based on the median normalized correlation value.