Compute Normalized Correlation (approximation)
Source:R/15_compute_norm_corr.R
computeNormalizedCorrelation.RdThis method calculates the normalized correlation between pairs of cell types based on CCA weights and the respective kernel matrix. It uses the spectral norm of the kernel matrix for normalization.
Usage
computeNormalizedCorrelation(object, tol = 1e-04, calculationMode = "perSlide")
# S4 method for class 'CoPro'
computeNormalizedCorrelation(object, tol = 1e-04)
# S4 method for class 'CoProMulti'
computeNormalizedCorrelation(object, tol = 1e-04, calculationMode = "perSlide")Value
The object with the normalized correlation value
between any pair of cell types
added as a new slot, normalizedCorrelation.
See also
runSkrCCA(), computeBidirCorrelation(),
computeGeneAndCellScores()
Other scores-and-correlation:
computeGeneAndCellScores()