Get cell score and location information as a data.frame
Source:R/80_get_cs_in_situ.r
getCellScoresInSitu.RdGet cell score and location information as a data.frame
Usage
getCellScoresInSitu(object, sigmaValueChoice, ccIndex = 1)
# S4 method for class 'CoProSingle'
getCellScoresInSitu(object, sigmaValueChoice, ccIndex = 1)
# S4 method for class 'CoProMulti'
getCellScoresInSitu(object, sigmaValueChoice, ccIndex = 1)