This method provides a summary of the CoPro object, including the number of cells, genes, slides, and cell types of interest. It also displays the processing steps completed and the parameters used.
This method provides a summary of the CoPro object, including the number of cells, genes, slides, and cell types of interest. It also displays the processing steps completed and the parameters used.